import { api, useStaff } from "@nice/client";
import { useMainContext } from "../../layout/MainProvider";
import toast from "react-hot-toast";
import { Button, Form, Input, Modal, Select } from "antd";
import { useEffect } from "react";
import TrainContentTreeSelect from "@web/src/components/models/trainContent/train-content-tree-select";
import DepartmentChildrenSelect from "@web/src/components/models/department/department-children-select";

export default function StaffModal() {
    const { data: traincontents} = api.trainSituation.findMany.useQuery({
        select:{
            id: true,
            trainContent:{
                select:{
                    id: true,
                    title: true,
                    type: true,
                }
            },
        }
        
    });
    // useEffect(() => {
    //     traincontents?.forEach((situation)=>{
    //         console.log(situation.id);
    //     });
    // }, [traincontents]);

    const { form, formValue, setVisible, visible, editingRecord, setEditingRecord } = useMainContext()
    const { create, update } = useStaff();
    const handleOk = async () => {
        const values = await form.getFieldsValue();
        // console.log(values);
        // console.log(values.position);
        try {
            if (editingRecord && editingRecord.id) {
                await update.mutateAsync({
                    where: { id: editingRecord.id },
                    data: {
                        username: values.username,
                        department: {
                            connect: { id: values.deptId }
                         },
                         rank: values.rank,
                         type: values.type,
                         showname: values.username,
                        updatedAt: new Date()
                    } , 
                });
                // console.log(result);
            } else {
                const result = await create.mutateAsync(
                    {
                        data: {
                            username: values.username,  
                            department: {
                                connect: { id: values.deptId }
                             },
                            createdAt: new Date(),
                            showname: values.username,
                            rank: values.rank,
                            type: values.type,
                        } as any,
                    }
                ) ;
            } 
            toast.success("保存成功");
            setVisible(false);
            setEditingRecord(null);
        } catch (error) {
            toast.error("保存失败");
            throw error;
        }
    };

    const handleCancel = () => {
        setVisible(false);
        setEditingRecord(null);
        form.resetFields();
    };

    useEffect(() => {
        if (visible&&editingRecord) {
            form.setFieldsValue(editingRecord);
        }
    }, [visible,editingRecord]);
    return (
        <>
            <Modal
                title="编辑员工信息"
                visible={visible}
                onOk={handleOk}
                onCancel={handleCancel}
            >
                <Form
                    form={form}
                    initialValues={formValue}
                >
                    <Form.Item
                        name={"username"}
                        label="姓名"
                    >
                        <Input className="rounded-lg" />
                    </Form.Item>
                    <Form.Item
                        name={"deptId"}
                        label="部门"
                    >
                        <DepartmentChildrenSelect></DepartmentChildrenSelect>
                    </Form.Item>
                    <Form.Item
                        name={["type"]}
                        label="人员类别"
                    >
                        <Input className="rounded-lg" />
                    </Form.Item>
                    
                    <Form.Item
                        name={["rank"]}
                        label="衔职"
                    >
                        <Input className="rounded-lg" />
                    </Form.Item>
                </Form>
            </Modal>
            {/* <Button onClick={() =>{console.log(traincontents);}}>TEST</Button> */}
        </>
    )
}